% Given to us by T070247
f1 = 9.096e6;
f2 = 45.481e6;
frequencies = [-f2 -f1 0 f1 f2];
TotalPower = [63.8 .16 82 .16 100];

% Generate the powers in each higher order mode
HOMindex      = 0:7;
MisAlignPower      = 0.02;
alpha = 1 / (1/MisAlignPower + 1);
HOMpower      = alpha.^(HOMindex);
HOMpower(1) = 0;
ModeMisMatchPercent = 0.05;
alpha = (1+sqrt(ModeMisMatchPercent) + ModeMisMatchPercent/2);

ModeMisMatchPower = [kappa(alpha,0)^4 0, ...
                     2*(kappa(alpha,0)*kappa(alpha,2))^2 0, ...
                     2*(kappa(alpha,0)*kappa(alpha,4))^2+kappa(alpha,2)^4 0, ...
                     2*(kappa(alpha,0)*kappa(alpha,6))^2+2*(kappa(alpha,2)*kappa(alpha,4))^2 0];
                 
HOMpower = HOMpower + ModeMisMatchPower;
HOMpower(1) = 1 - MisAlignPower - ModeMisMatchPercent;

HOMandRF = reshape(HOMpower'*TotalPower, [], 1);
FreqAndHOMidx = [ -f2*ones(8,1) HOMindex';
                  -f1*ones(8,1) HOMindex';
                    0*ones(8,1) HOMindex';
                   f1*ones(8,1) HOMindex';
                   f2*ones(8,1) HOMindex'];

    
% some functions we'll need
g_factor = @(L,R) 1-L/R;
GouyPhase = @(L,R) acos(g_factor(L,R))*180/pi;
waist = @(L,R) sqrt(1.064e-6*cavHG(L, R, R)/pi);

%% Input spectrum
% Here we calculate the aLIGO input spectrum assuming L1 OMC
% characteristics
L1gouy = 2*43.8 * pi/180;    % Round trip Gouy phase for L1 eLIGO OMC
L1FSR  = 295.2e6;
L1F    = 360;

df = -L1FSR:1000:L1FSR;

sbPower = makeSB(df,HOMandRF, FreqAndHOMidx, L1FSR, L1F, L1gouy);
totalPower = sum(sbPower,2);
extraPower = totalPower - HOMandRF(17)*makeFringe(df,0, L1FSR, L1F, L1gouy, 0).';

%% display it
figure(1);
clf;

plotData(df, totalPower, extraPower, sbPower);

%% Parameter scan
gPhaseScan = (65:0.1:85)*pi/180;
RR = [1 1.5  2  2.5 3];
L = 0.35:0.001:0.9;
% multiple g
gPower = zeros(length(L),length(RR));
thisF = 400;

for rr = 1:length(RR)
    g = 1-L/RR(rr);
    gPhaseScan = 2*acos(g);

    nG = length(gPhaseScan);

    for jj = 1:nG
        for ii = 1:length(HOMandRF)
            fRF = FreqAndHOMidx(ii,1);
            n   = FreqAndHOMidx(ii,2);
            thisFSR = c/(2*L(jj));
            gPower(jj,rr) = HOMandRF(ii)*makeFringe(0, fRF, thisFSR, thisF, gPhaseScan(jj), n)+gPower(jj,rr);
        end
        gPower(jj,rr) = gPower(jj,rr) - HOMandRF(17)*makeFringe(0,0,thisFSR, thisF, gPhaseScan(jj),0);
    end
end



figure(4)
clf;
L1omcL = .508;
FiveL  = 0.4;
ThreeL = 0.83;
set(gca, 'FontSize', 16);
%semilogy(gPhaseScan*180/pi, gPower);
junkPower = sum(HOMandRF) - HOMandRF(17);
L1fact    = interp1(L,  1./gPower*junkPower, L1omcL);
FiveFact  = interp1(L,  1./gPower*junkPower, FiveL);
ThreeFact = interp1(L,  1./gPower*junkPower, ThreeL);

a = plot(L, 1./gPower*junkPower, '-', ...
         L1omcL, L1fact(3), 'or', ...
        FiveL, FiveFact(3), 'vr', ...
        ThreeL, ThreeFact(3), 'dr');
set(a, 'MarkerFaceColor', [1 0 0], 'MarkerSize', 10);

ylabel('Attenuation');
xlabel('Length [m]');
legend('1.0 m', '1.5 m', '2.0 m', '2.5 m', '3.0 m', 'Location', 'NorthWest');
axis('tight');

%% Different Gouy Phase contributions
figure(2)
goodGouy = 109*pi/180;
goodG = cos(goodGouy/2);
L = (1-goodG)*R; 
FSR = c/(2*L);
Finesse = 400;
df = -FSR:1e3:FSR;

sbPower = makeSB(df,HOMandRF, FreqAndHOMidx, FSR, Finesse, goodGouy);
totalPower = sum(sbPower,2);
extraPower = totalPower - HOMandRF(17)*makeFringe(df,0, FSR, Finesse, goodGouy, 0).';

plotData(df, totalPower, extraPower, sbPower);

%% This is the good Gouy phase
figure(3)
R = 2.0;
L = 0.714; 
g = 1-L/R;
goodGouy = 2*acos(g);
FSR = c/(2*L);
df = -FSR:1e3:FSR;

sbPower = makeSB(df,HOMandRF, FreqAndHOMidx, FSR, Finesse, goodGouy);
totalPower = sum(sbPower,2);
extraPower = totalPower - HOMandRF(17)*makeFringe(df,0, FSR, Finesse, goodGouy, 0).';

plotData(df, totalPower, extraPower, sbPower);


%% Mode spacing
% for each HOM of each RF,  calculate the spacing for each length
L = 0.35:1e-3:.9;
FSR = c./(2*L);
R = 2;
g = 1-L/R;
phi_g = 2*acos(g);

minSpacing = [];
for ii = 1:length(phi_g)
    df = FreqAndHOMidx(:,1)+FreqAndHOMidx(:,2)*phi_g(ii)/(2*pi)*FSR(ii);
    spacing = mod(df, FSR(ii));
    spacing(17) = [];
    [minSpacing(ii,1) minSpacing(ii,2)] = min(abs(spacing/FSR(ii)));
end

figure(5)
clf;

%subplot(2,1,1)
set(gca, 'FontSize', 16);
plot(L, minSpacing(:,1), '-', ...
     L, f1./FSR, 'k--');
 
xlabel('Length [m]');
ylabel('Nearest mode [\delta f / FSR]');
axis('tight');

%subplot(2,1,2)
%plot(L, minSpacing(:,2))



