function [x,y,r] = findMaxCircle(L,R,modeDistance, Cutoff)
% function [x,y,r] = findMaxCircle(L,R,modeDistance, Cutoff)
%
%

dMax = max(modeDistance(:));
blackWhite = im2bw(modeDistance/ dMax, Cutoff/dMax);

props = regionprops(blackWhite, {'Centroid', 'Area', 'MajorAxisLength', 'MinorAxisLength', 'Orientation'});

[mm,idx] = max([props(:).Area]);

xslope = R(2)-R(1);
yslope = L(2)-L(1);

x = xslope*props(idx).Centroid(1) + R(1);
y = yslope*props(idx).Centroid(2) + L(1);
r = props(idx).Area *xslope*yslope;


clf;
cc = [0 0.5 0.9];
set(gca, 'FontSize', 16);
imagesc(R,L,modeDistance);
set(gca, 'YDir', 'Normal');
ellipseAngle = -atan(yslope/xslope*tan(props(idx).Orientation/180*pi));
dLdR = tan(ellipseAngle);
[tmp, h] = ellipse( xslope*props(idx).MajorAxisLength/2, ...
            yslope*props(idx).MinorAxisLength/2, ...
            ellipseAngle, ...
            x, y);
set(h, 'LineWidth', 3, 'Color', [0 0.5 .9 ]);         
colorbar;
xlabel('Radius [m]');
ylabel('Length [m]');

nIDX = length(R);
fIdx = floor(0.07*nIDX);
a(1) = text(R(fIdx), L(end-fIdx), ...
            sprintf('df > %d \nR = %.3f m\nL = %.3f m\ndL/dR = %.3f\nArea = %.0f cm^{2}', ...
                    Cutoff, x, y, dLdR, r*1e4));
set(a, 'BackgroundColor', [.9 .9 .9], 'FontSize', 16);

hold on;
plot(x,y, 'o', 'MarkerSize', 12, 'Color', [0 0.5 0.9], 'MarkerFaceColor', cc);
dx = [-0.1 0.1];
a = line(x + dx, y + dLdR*dx); 
set(a, 'LineStyle', '--', 'Color', [0 0.5 0.9], 'LineWidth', 2);
hold off;




