function [idx, df] = findNearestMode(L, R, Finesse, Frequency, Nrange)
% function [idx] = findNearestMode(L, R, Finesse, Frequency)
%
% returns the lowest order HOM for the cavity of 
%
%  L          length      [m]
%  R          mirror ROC  [m]
%  Finesse    Finesse
%  Frequency  RF sideband frequency [Hz]
%  Nrange     Number of FSRs away from resonance 
%
%  Calculates the lowest order HOM that falls within +/- Nrange*FSR of the
%  TEM00 carrier field.
%
%  Assumes a linear,  symmetric cavity
%

c = 299692458;            % m/s
FSR = c/(2*L);            % Free spectral range,  Hz
g = 1-L/R;                % g-factor
Phi_g = 180/pi*acos(g);   % HOM phase shift [deg]
f_hom = Phi_g * FSR/360;  % HOM frequency shift [Hz]
f_bw = FSR/Finesse;       % linewidth (Hz)

f_res = @(N_hom) mod(N_hom*f_hom + Frequency, FSR);

for ii = 1:100
    if f_res(ii) < Nrange * f_bw 
        idx = ii;
        df = f_res(ii);
        return;
    elseif FSR-f_res(ii) < Nrange * f_bw
        idx = ii;
        df = f_res(ii)-FSR;
        return;
    else 
        idx = ii;
        df = f_res(ii);
    end
end

        



